@@ -21,28 +21,29 @@ print "ok .. 0\n";
 
 chdir "test/" or die "ERROR: cannot change dir to test/";
 
-$ret = `./creat.pl 2>&1 >log.1`;
+$ret = `./creat.pl 2>&1 >../logs/log.1`;
 if( $? != 0 ) { die "ERROR: not ok 1" };
 print "ok .. 1\n";
 
-$ret = `./alpha.pl 2>&1 >log.2`;
+$ret = `./alpha.pl 2>&1 >../logs/log.2`;
 if( $? != 0 ) { die "ERROR: not ok 2" };
 print "ok .. 2\n";
 
-$ret = `./beta.pl 2>&1 >log.3`;
+$ret = `./beta.pl 2>&1 >../logs/log.3`;
 if( $? != 0 ) { die "ERROR: not ok 3" };
 print "ok .. 3\n";
 
-$ret = `./gamma.pl 2>&1 >log.4`;
+$ret = `./gamma.pl 2>&1 >../logs/log.4`;
 if( $? != 0 ) { die "ERROR: not ok 4" };
 print "ok .. 4\n";
 
-$ret = `./delta.pl 2>&1 >log.5`;
+$ret = `./delta.pl 2>&1 >../logs/log.5`;
 if( $? != 0 ) { die "ERROR: not ok 5" };
 print "ok .. 5\n";
 
-$ret = `./epsilon.pl 2>&1 >log.6`;
+$ret = `./epsilon.pl 2>&1 >../logs/log.6`;
 if( $? != 0 ) { die "ERROR: not ok 6" };
 print "ok .. 6\n";
 
+print "\nAll tests ok.\n\n";
 exit 0;
